Hello. I work for Business Management Systems in Fairfax, VA. There is a problem with:

> %mfrom

not accepting DSNs for emails sent from that domain.

We and possibly many other ISPs require mail servers contacting us to follow the minimum requirements for the functioning of mail over the Internet by adhering to RFC 2821 (and others), which requires that a mail server accept for the purpose of error reporting the null email address ("<>") in the `MAIL FROM:` command. See

RFC 2821
  section 4.1.1.2 MAIL (BNF grammar)
  section 6.1 Reliable Delivery and Replies by Email (para. 2)
  ftp://ftp.rfc-editor.org/in-notes/rfc2821.txt
RFC 2505
  section 2. Recommendations 6a)
  section 2.6.1. "MAIL From: <>"
  ftp://ftp.rfc-editor.org/in-notes/rfc2505.txt
RFC 1123
  section 5.2.9 Command Syntax: RFC-821 Section 4.1.2
  ftp://ftp.rfc-editor.org/in-notes/rfc1123.txt
RFC 821 (obsoleted by RFC 2821)
  section 4.1.2 ftp://ftp.rfc-editor.org/in-notes/rfc821.txt

Your domain "%mfrom" no longer accepts <>. The need for the null address ("<>") as an error reporting tool for mail server software is VERY important to the correct functioning of mail over the Internet. It provides legitimate users a means of find out if mail failed to arrive at its intended destination. Blocking this for the purpose of spam control is unacceptable, because legitimate users will never know that mail might have been rejected because they simply mistyped the destination address, or that a mail box is full, or no longer active, etc. You can control forged DSNs by using a BATV scheme.

Furthermore, many ESPs, for example verizon.net, validate the return-path of incoming emails by calling back to an MX for the domain. With DSNs not functioning, you will be unable to send emails to verizon.net and other mail servers that valid the return-path.

We ask if you would kindly contact those responsible for the "%mfrom" mail servers or if you have the means yourselves to resolve the issue so that "%mfrom" remains RFC compliant with respect to the use of the null address ("<>"). It is only a matter of time before some very important email goes undelivered and no one is notified of the problem.

Thank you for your time and attention in this matter,